@@ -1,5 +1,13 @@
 #!/bin/bash
 
+#
+# Copyright (c) 2013-2019 Commonwealth Computer Research, Inc.
+# All rights reserved. This program and the accompanying materials
+# are made available under the terms of the Apache License, Version 2.0 which
+# accompanies this distribution and is available at
+# http://www.opensource.org/licenses/apache2.0.php.
+#
+
 # Verify that we are running in sudo mode
 if [[ "$EUID" -ne 0 ]]; then
   echo "ERROR: Please run in sudo mode"
@@ -11,14 +19,14 @@ GMUSER=hadoop
 # todo bootstrap from the current running location and ask the user if they want to 
 # install to /opt/geomesa ? Maybe propmpt with a default of /opt/geomesa similar to
 # how the maven release plugin works?
-GMDIR="/opt/geomesa-hbase_2.11-2.1.4"
+GMDIR="/opt/geomesa-hbase_2.11-2.4.2"
 
 if [[ ! -d "${GMDIR}" ]]; then
   echo "Unable to find geomesa directory at ${GMDIR}"
   exit 1
 fi
 
-echo "Bootstrapping GeoMesa HBase with version 2.1.4 installed at ${GMDIR}"
+echo "Bootstrapping GeoMesa HBase with version 2.4.2 installed at ${GMDIR}"
 
 pip install --upgrade awscli
 
@@ -51,7 +59,7 @@ ROOTDIR="${ROOTDIR%/}" # standardize to remove trailing slash
 chown -R $GMUSER:$GMUSER ${GMDIR}
 
 # Configure coprocessor auto-registration
-DISTRIBUTED_JAR_NAME=geomesa-hbase-distributed-runtime_2.11-2.1.4.jar
+DISTRIBUTED_JAR_NAME=geomesa-hbase-distributed-runtime_2.11-2.4.2.jar
 
 NL=$'\n'
 echo The HBase Root dir is ${ROOTDIR}.
@@ -59,7 +67,8 @@ echo "# Auto-registration for geomesa coprocessors ${NL}export CUSTOM_JAVA_OPTS=
 
 # Deploy the GeoMesa HBase distributed runtime to the HBase root directory
 if [[ "$ROOTDIR" = s3* ]]; then
-  aws s3 cp /opt/geomesa/dist/hbase/$DISTRIBUTED_JAR_NAME ${ROOTDIR}/lib/ && \
+  availabilityZone=$(wget -q -O - http://169.254.169.254/latest/meta-data/placement/availability-zone) # Static metadata service
+  aws --region ${availabilityZone::-1} s3 cp /opt/geomesa/dist/hbase/$DISTRIBUTED_JAR_NAME ${ROOTDIR}/lib/ && \
   echo "Installed GeoMesa distributed runtime to ${ROOTDIR}/lib/"
 elif [[ "$ROOTDIR" = hdfs* ]]; then
   local libdir="${ROOTDIR}/lib"
