@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
-# Copyright (c) 2013-2016 Commonwealth Computer Research, Inc.
+# Copyright (c) 2013-2019 Commonwealth Computer Research, Inc.
 # All rights reserved. This program and the accompanying materials
 # are made available under the terms of the Apache License, Version 2.0 which
 # accompanies this distribution and is available at
@@ -89,8 +89,8 @@ function downloadUrls() {
     for url in "${urls[@]}"; do
       fname="$(basename "$url")" # filename we'll save to
       tmpfile=$(mktemp)
-      # -sS disables progress meter but keeps error messages, -f don't save failed files, -o write to destination file
-      downloads+=("(echo fetching $fname && curl -sSfo '$tmpfile' '$url' && mv '$tmpfile' '${dest}/${fname}' && chmod 644 '${dest}/${fname}') || echo [ERROR] Failed to fetch $fname")
+      # -sS disables progress meter but keeps error messages, -f don't save failed files, -o write to destination file, -L follow redirects
+      downloads+=("(echo fetching $fname && curl -LsSfo '$tmpfile' '$url' && mv '$tmpfile' '${dest}/${fname}' && chmod 644 '${dest}/${fname}') || echo [ERROR] Failed to fetch $fname")
     done
     # pass to xargs to run with 4 threads
     # delimit with null char to avoid issues with spaces
@@ -441,8 +441,3 @@ if [[ -n "$JAVA_LIBRARY_PATH" ]]; then
   GEOMESA_OPTS="${GEOMESA_OPTS} -Djava.library.path=${JAVA_LIBRARY_PATH}"
   export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$JAVA_LIBRARY_PATH"
 fi
-
-# Configure Java Options this can be set in geomesa-env.
-if [[ -z "$CUSTOM_JAVA_OPTS" ]]; then
-  export CUSTOM_JAVA_OPTS="${JAVA_OPTS}"
-fi
