@@ -1,7 +1,7 @@
 #!/bin/bash
 
 #
-# Copyright (c) 2013-2016 Commonwealth Computer Research, Inc.
+# Copyright (c) 2013-2019 Commonwealth Computer Research, Inc.
 # All rights reserved. This program and the accompanying materials
 # are made available under the terms of the Apache License, Version 2.0 which
 # accompanies this distribution and is available at
@@ -12,8 +12,8 @@
 # into a given directory. Usually this is used to install the deps into either the
 # geomesa tools lib dir or the WEB-INF/lib dir of geoserver.
 
-hadoop_version="2.8.4"
-zookeeper_version="3.4.10"
+hadoop_version="2.8.5"
+zookeeper_version="3.5.6"
 
 # this version required for hadoop 2.8, earlier hadoop versions use 3.1.0-incubating
 htrace_core_version="4.1.0-incubating"
@@ -52,6 +52,15 @@ declare -a urls=(
   "${base_url}com/yammer/metrics/metrics-core/2.2.0/metrics-core-2.2.0.jar"
 )
 
+zk_maj_ver="$(expr match "$zookeeper_version" '\([0-9][0-9]*\)\.')"
+zk_min_ver="$(expr match "$zookeeper_version" '[0-9][0-9]*\.\([0-9][0-9]*\)')"
+zk_bug_ver="$(expr match "$zookeeper_version" '[0-9][0-9]*\.[0-9][0-9]*\.\([0-9][0-9]*\)')"
+
+# compare the version of zookeeper to determine if we need zookeeper-jute (version >= 3.5.5)
+if [[ "$zk_maj_ver" -ge 3 && "$zk_min_ver" -ge 5 && "$zk_bug_ver" -ge 5 ]]; then
+  urls+=("${base_url}org/apache/zookeeper/zookeeper-jute/$zookeeper_version/zookeeper-jute-$zookeeper_version.jar")
+fi
+
 # compare the first digit of htrace core version to determine the artifact name
 if [[ "${htrace_core_version%%.*}" -lt 4 ]]; then
   urls+=("${base_url}org/apache/htrace/htrace-core/${htrace_core_version}/htrace-core-${htrace_core_version}.jar")
@@ -65,3 +74,4 @@ if [ -z "$(find -L $install_dir -maxdepth 1 -name 'guava-*' -print -quit)" ]; th
 fi
 
 downloadUrls "$install_dir" urls[@]
+
